###############################################################################
## CREATE A LAND-SEA MASK FROM SEA SALT FIELD, FOR SURFACE OR MULTILEVEL
###############################################################################
##
## Description
##    This script creates a land-sea mask netcdf file from an EC-Earth/NEMO
##    netcdf file. Where there is no sea salt, there is land, otherwise there is
##    sea. When variable $lsm is set to lsm a surface lsm is created from field
##    sosaline, if $lsm is set to lsm3d a multilevel field is create from field
##    vosaline.
## Notes
##    nco (NetCDF operators) must be installed on your system
##
## Modification history
##    20141204-A_vanu_be: written.
##
###############################################################################
#-------------------------------------------------------------------------------
# User definitions
#-------------------------------------------------------------------------------
# make surface (lsm) or multilevel (lsm3d) land sea mask
set -xuve
module load NCO
lsm=%LSM%                          # lsm | lsm3d

# set paths
wdir=%CURRENT_ROOTDIR%
if [ $lsm = "lsm" ]; then
    infile=%EXPERIMENT%_%SOSALINE_FILE%_%STARTDATE%_*_grid_T.nc
else
    infile=%EXPERIMENT%_%VOSALINE_FILE%_%STARTDATE%_*_grid_T.nc
fi
outfile=${lsm}_mask.nc

#-------------------------------------------------------------------------------
# No more user input required below
#-------------------------------------------------------------------------------
# goto working directory and remove any existing output files
cd $wdir
rm -f $outfile
rm -f tmp*_$outfile

# Define which fields to use and the properties
if [ $lsm = "lsm" ]; then
  infield=sosaline
  copyflds="$lsm,nav_lon,nav_lat"
  associate="nav_lat nav_lon"
  axis="YX"
elif [ $lsm = "lsm3d" ]; then
  infield=vosaline
  copyflds="$lsm,nav_lon,nav_lat,deptht"
  associate="deptht nav_lat nav_lon"
  axis="ZYX"
else
  echo "Unknown lsm type $lsm"
  exit 1
fi

# create lsm
echo "Creating $lsm from $infile"

ncap2 -s "$lsm=int($infield==0.0)" $infile tmp1_$outfile
ncwa -a time_counter tmp1_$outfile tmp2_$outfile
ncks -v $copyflds tmp2_$outfile $outfile

# adapt attributes
echo "Setting attributes"
ncatted -O -a associate,$lsm,o,c,"$associate" $outfile
ncatted -O -a axis,$lsm,o,c,$axis $outfile
ncatted -O -a units,$lsm,o,c,1 $outfile
ncatted -O -a standard_name,$lsm,o,c,land_sea_mask $outfile
ncatted -O -a short_name,$lsm,o,c,land_sea_mask $outfile
ncatted -O -a long_name,$lsm,o,c,"Land sea mask" $outfile
ncatted -O -a valid_min,$lsm,d,, $outfile
ncatted -O -a valid_max,$lsm,d,, $outfile
ncatted -O -a missing_value,$lsm,d,, $outfile
ncatted -O -a online_operation,$lsm,d,, $outfile
ncatted -O -a interval_write,$lsm,d,, $outfile
ncatted -O -a interval_operation,$lsm,d,, $outfile

# clean up
rm tmp*_$outfile

# done
echo "Created $outfile"
